@@ -163,7 +163,7 @@ class CondaEnv:
             "import lb.nightly.functions",
         ]
         try:
-            run(cmd, check=True, capture_output=True)
+            run(cmd, env={"PATH": self.bin_dir}, check=True, capture_output=True)
         except CalledProcessError as err:
             logger.error("lb.nightly.functions not available in the environment")
             raise EnvironmentError(err.stderr.decode())
